@@ -22,7 +22,7 @@ try:
     from __init__ import __version__
     from allelecall import BBACA
     from createschema import PPanGen
-    from SchemaEvaluator import ValidateSchema
+    from SchemaEvaluator import schema_evaluator
     from PrepExternalSchema import PrepExternalSchema
     from utils import (TestGenomeQuality, profile_joiner,
                        uniprot_find, Extract_cgAlleles,
@@ -39,7 +39,7 @@ except:
     from CHEWBBACA import __version__
     from CHEWBBACA.allelecall import BBACA
     from CHEWBBACA.createschema import PPanGen
-    from CHEWBBACA.SchemaEvaluator import ValidateSchema
+    from CHEWBBACA.SchemaEvaluator import schema_evaluator
     from CHEWBBACA.PrepExternalSchema import PrepExternalSchema
     from CHEWBBACA.utils import (TestGenomeQuality, profile_joiner,
                                  uniprot_find, Extract_cgAlleles,
@@ -62,22 +62,22 @@ def create_schema():
     def msg(name=None):
         # simple command to create schema from genomes
         simple_cmd = ('chewBBACA.py CreateSchema -i <input_files> '
-                                                '-o <output_directory> '
-                                                '-ptf <ptf_path>')
+                      '-o <output_directory> '
+                      '-ptf <ptf_path>')
         # command to create schema from genomes with non-default parameters
         params_cmd = ('chewBBACA.py CreateSchema -i <input_files> '
-                                                '-o <output_directory> '
-                                                '--ptf <ptf_path>\n'
-                                                '\t\t\t    --cpu <cpu_cores> '
-                                                '--bsr <blast_score_ratio> '
-                                                '--l <minimum_length>\n'
-                                                '\t\t\t    --t <translation_table> '
-                                                '--st <size_threshold>')
+                      '-o <output_directory> '
+                      '--ptf <ptf_path>\n'
+                      '\t\t\t    --cpu <cpu_cores> '
+                      '--bsr <blast_score_ratio> '
+                      '--l <minimum_length>\n'
+                      '\t\t\t    --t <translation_table> '
+                      '--st <size_threshold>')
         # command to create schema from single FASTA
         cds_cmd = ('chewBBACA.py CreateSchema -i <input_file> '
-                                             '-o <output_directory> '
-                                             '--ptf <ptf_path> '
-                                             '--CDS')
+                   '-o <output_directory> '
+                   '--ptf <ptf_path> '
+                   '--CDS')
 
         usage_msg = ('\nCreate schema from input genomes:\n  {0}\n'
                      '\nCreate schema from input genomes with non-default parameters:\n  {1}\n'
@@ -216,18 +216,18 @@ def allele_call():
     def msg(name=None):
         # simple command to perform AlleleCall with schema deafult parameters
         simple_cmd = ('chewBBACA.py AlleleCall -i <input_files> '
-                                              '-g <schema_directory> '
-                                              '-o <output_directory> ')
+                      '-g <schema_directory> '
+                      '-o <output_directory> ')
         # command to perform AlleleCall with non-default parameters
         params_cmd = ('chewBBACA.py AlleleCall -i <input_files> '
-                                              '-g <schema_directory> '
-                                              '-o <output_directory> '
-                                              '--ptf <ptf_path>\n'
-                                              '\t\t\t  --cpu <cpu_cores> '
-                                              '--bsr <blast_score_ratio> '
-                                              '--l <minimum_length>\n'
-                                              '\t\t\t  --t <translation_table> '
-                                              '--st <size_threshold>')
+                      '-g <schema_directory> '
+                      '-o <output_directory> '
+                      '--ptf <ptf_path>\n'
+                      '\t\t\t  --cpu <cpu_cores> '
+                      '--bsr <blast_score_ratio> '
+                      '--l <minimum_length>\n'
+                      '\t\t\t  --t <translation_table> '
+                      '--st <size_threshold>')
         # command to perform AlleleCall with single Fasta file
         # cds_cmd = ('chewBBACA.py AlleleCall -i <input_file> '
         #                                    '-o <output_directory> '
@@ -236,7 +236,7 @@ def allele_call():
 
         usage_msg = ('\nPerform AlleleCall with schema default parameters:\n  {0}\n'
                      '\nPerform AlleleCall with non-default parameters:\n  {1}\n'.format(simple_cmd, params_cmd))
-                     #'\nPerform AlleleCall with single FASTA file that contains coding sequences:\n  {2}'.format(simple_cmd, params_cmd, cds_cmd))
+        # '\nPerform AlleleCall with single FASTA file that contains coding sequences:\n  {2}'.format(simple_cmd, params_cmd, cds_cmd))
 
         return usage_msg
 
@@ -335,7 +335,7 @@ def allele_call():
                              'are temporary files from a previous '
                              'process that was interrupted.')
 
-    parser.add_argument('--db', required=False, action='store_false',
+    parser.add_argument('--db', required=False, action='store_true',
                         dest='store_profiles',
                         help='If the profiles in the output matrix '
                              'should be stored in the local SQLite '
@@ -371,6 +371,13 @@ def allele_call():
 
     timeout = 30
 
+    # change schema's directory value if user provided file with list of genes
+    genes_list = schema_directory
+    if os.path.isfile(schema_directory) is True:
+        with open(genes_list, 'r') as f:
+            schema_directory = f.readline().strip()
+            schema_directory = os.path.dirname(schema_directory)
+
     # check parameters values in config file and alter if needed
     config_file = os.path.join(schema_directory, '.schema_config')
 
@@ -439,9 +446,12 @@ def allele_call():
     if len(unmatch_params) > 0:
         print('Provided arguments values differ from arguments '
               'values used for schema creation:\n')
-        params_diffs = [[p, ':'.join(map(str, schema_params[p])), str(unmatch_params[p])] for p in unmatch_params]
-        params_diffs_text = ['{:^20} {:^20} {:^10}'.format('Argument', 'Schema', 'Provided')]
-        params_diffs_text += ['{:^20} {:^20} {:^10}'.format(p[0], p[1], p[2]) for p in params_diffs]
+        params_diffs = [[p, ':'.join(map(str, schema_params[p])), str(
+            unmatch_params[p])] for p in unmatch_params]
+        params_diffs_text = ['{:^20} {:^20} {:^10}'.format(
+            'Argument', 'Schema', 'Provided')]
+        params_diffs_text += ['{:^20} {:^20} {:^10}'.format(
+            p[0], p[1], p[2]) for p in params_diffs]
         print('\n'.join(params_diffs_text))
         if force_continue is False:
             prompt = ('\nContinuing might lead to results not consistent with '
@@ -462,7 +472,8 @@ def allele_call():
     # default is to get the training file in schema directory
     if run_params['prodigal_training_file'] is False:
         # deal with multiple training files
-        schema_ptfs = [file for file in os.listdir(schema_directory) if file.endswith('.trn')]
+        schema_ptfs = [file for file in os.listdir(
+            schema_directory) if file.endswith('.trn')]
         if len(schema_ptfs) > 1:
             sys.exit('Found more than one Prodigal training file in schema directory.\n'
                      'Please maintain only the training file used in the schema creation process.')
@@ -492,7 +503,8 @@ def allele_call():
                           'schema for usage with the NS.\nContinue process?\n')
                 ptf_answer = aux.input_timeout(prompt, timeout)
             if ptf_num > 1:
-                print('Prodigal training file is not any of the {0} used in previous runs.'.format(ptf_num))
+                print('Prodigal training file is not any of the {0} used in previous runs.'.format(
+                    ptf_num))
                 prompt = ('Continue?\n')
                 ptf_answer = aux.input_timeout(prompt, timeout)
         else:
@@ -511,7 +523,7 @@ def allele_call():
 
     # if is a fasta pass as a list of genomes with a single genome,
     # if not check if is a folder or a txt with a list of paths
-    schema_genes = aux.check_input_type(schema_directory, 'listGenes2Call.txt')
+    schema_genes = aux.check_input_type(genes_list, 'listGenes2Call.txt')
     genomes_files = aux.check_input_type(input_files, 'listGenomes2Call.txt')
 
     # determine if schema was downloaded from the Chewie-NS
@@ -533,12 +545,15 @@ def allele_call():
         # create datetime objects and sort to get latest
         insert_dates = [(file, datetime.datetime.strptime(file.split('_')[-1], '%Y%m%dT%H%M%S'))
                         for file in results_folders]
-        sorted_insert_dates = sorted(insert_dates, key=lambda x: x[1], reverse=True)
-        results_matrix = os.path.join(sorted_insert_dates[0][0], 'results_alleles.tsv')
+        sorted_insert_dates = sorted(
+            insert_dates, key=lambda x: x[1], reverse=True)
+        results_matrix = os.path.join(
+            sorted_insert_dates[0][0], 'results_alleles.tsv')
         insert_date = sorted_insert_dates[0][0].split('_')[-1]
 
         # verify that database directory exists
-        database_directory = os.path.join(schema_directory, 'profiles_database')
+        database_directory = os.path.join(
+            schema_directory, 'profiles_database')
         # create if it does not exist
         if os.path.isdir(database_directory) is False:
             os.mkdir(database_directory)
@@ -554,15 +569,18 @@ def allele_call():
                 print('done.')
                 print('Inserted {0} loci into database.'.format(total_loci))
             except Exception:
-                print('WARNING: Could not create database file. Will not store profiles.')
+                print(
+                    'WARNING: Could not create database file. Will not store profiles.')
 
         # insert whole matrix
         if os.path.isfile(database_file) is not False:
             print('\nSending allelic profiles to SQLite database...', end='')
             try:
-                total_profiles = sq.insert_allelecall_matrix(results_matrix, database_file, insert_date)
+                total_profiles = sq.insert_allelecall_matrix(
+                    results_matrix, database_file, insert_date)
                 print('done.')
-                print('Inserted {0} profiles ({1} total, {2} total unique).'.format(total_profiles[0], total_profiles[1], total_profiles[2]))
+                print('Inserted {0} profiles ({1} total, {2} total unique).'.format(
+                    total_profiles[0], total_profiles[1], total_profiles[2]))
             except Exception as e:
                 print(e)
                 print('WARNING: Could not store profiles in local database.')
@@ -580,10 +598,11 @@ def evaluate_schema():
     def msg(name=None):
         # simple command to evaluate schema or set of loci
         simple_cmd = ('chewBBACA.py SchemaEvaluator -i <input_files> '
-                                                   '-l <output_file> '
-                                                   '--cpu <cpu_cores>')
+                      '-l <output_file> '
+                      '--cpu <cpu_cores>')
 
-        usage_msg = ('\nEvaluate schema with default parameters:\n  {0}\n'.format(simple_cmd))
+        usage_msg = (
+            '\nEvaluate schema with default parameters:\n  {0}\n'.format(simple_cmd))
 
         return usage_msg
 
@@ -601,55 +620,52 @@ def evaluate_schema():
     parser.add_argument('SchemaEvaluator', nargs='+',
                         help='Evaluates a set of loci.')
 
-    parser.add_argument('-i', type=str, required=True,
+    parser.add_argument('-i', '--input-files', type=str, required=True,
                         dest='input_files',
                         help='Path to the schema\'s directory or path to a file containing '
                              'the paths to the FASTA files of the loci that will be evaluated, '
                              'one per line.')
 
-    parser.add_argument('-l', type=str, required=True,
+    parser.add_argument('-o', '--output', type=str, required=True,
                         dest='output_file',
-                        help='Path to the output HTML file.')
+                        help='Path to the output directory where the report HTML '
+                             'files will be generated.')
 
-    parser.add_argument('-p', action='store_true', required=False,
-                        default=False, dest='conserved',
-                        help='If all alleles must be within the threshold for the '
-                             'locus to be considered as having low length variability.')
-
-    parser.add_argument('--log', action='store_true', default=False,
-                        dest='log_scale',
-                        help='Apply log scale transformation to the yaxis '
-                             'of the plot with the number of alleles per locus.')
-
-    parser.add_argument('-ta', type=int, required=False,
+    parser.add_argument('--ta', '--translation-table', type=int, required=False,
                         default=11, dest='translation_table',
                         help='Genetic code used to translate coding '
                              'sequences.')
 
-    parser.add_argument('-t', type=float, required=False,
+    parser.add_argument('--th', '--threshold', type=float, required=False,
                         default=0.05, dest='threshold',
                         help='Allele size variation threshold. If an allele has '
                              'a size within the interval of the locus mode -/+ '
                              'the threshold, it will be considered a conserved '
                              'allele.')
 
-    parser.add_argument('--title', type=str, required=False,
-                        default='My Analyzed wg/cg MLST Schema - Rate My Schema',
-                        dest='title',
-                        help='Title displayed on the html page.')
+    parser.add_argument('--ml','--minimum-length', type=pv.minimum_sequence_length_type,
+                        required=False, default=201, dest='minimum_length',
+                        help='Minimum sequence length accepted for a '
+                        'coding sequence to be included in the schema.')
+
+    parser.add_argument('--cons', '--conserved', action='store_true',
+                        required=False, dest='conserved',
+                        help='If all alleles must be within the threshold for the '
+                                'locus to be considered as having low length variability.')
 
     parser.add_argument('--cpu', type=int, required=False,
                         default=1, dest='cpu_cores',
                         help='Number of CPU cores to use to run the process.')
 
-    parser.add_argument('-s', type=int, required=False,
-                        default=500, dest='split_range',
-                        help='Number of boxplots displayed in the plot area (more than '
-                             '500 can lead to performance issues).')
-
     parser.add_argument('--light', action='store_true', required=False,
-                        default=False, dest='light_mode',
-                        help='Skip clustal and mafft.')
+                        dest='light_mode',
+                        help='Skips the indepth analysis of the individual '
+                             'schema loci, including MAFFT.')
+
+    parser.add_argument('--no-cleanup', action='store_true', required=False,
+                        dest='no_cleanup',
+                        help='Stops the removal of intermediate files created '
+                             'during the report generation.')
 
     args = parser.parse_args()
 
@@ -659,19 +675,112 @@ def evaluate_schema():
 
     input_files = args.input_files
     output_file = args.output_file
-    log_scale = args.log_scale
     translation_table = args.translation_table
-    cpu_cores = args.cpu_cores
     threshold = args.threshold
+    minimum_length = args.minimum_length
     conserved = args.conserved
-    split_range = args.split_range
+    cpu_cores = args.cpu_cores
     light_mode = args.light_mode
-    title = str(args.title)
+    no_cleanup = args.no_cleanup
 
-    ValidateSchema.main(input_files, cpu_cores, output_file,
-                        translation_table, threshold, split_range,
-                        title, log_scale, conserved,
-                        light_mode)
+    cpu_to_use = aux.verify_cpu_usage(cpu_cores)
+
+    # check if input file path exists
+    if not os.path.exists(input_files):
+        sys.exit("Input argument is not a valid directory. Exiting...")
+
+    # check if the schema was created with chewBBACA
+    config_file = os.path.join(input_files, ".schema_config")
+    if os.path.exists(config_file):
+        # get the schema configs
+        with open(config_file, "rb") as cf:
+            chewie_schema_configs = pickle.load(cf)
+        print("This schema was created with chewBBACA {0}.".format(
+            chewie_schema_configs["chewBBACA_version"][0]))
+
+        # create pre-computed data
+        pre_computed_data_path = schema_evaluator.create_pre_computed_data(
+            input_files,
+            translation_table, 
+            output_file, 
+            cpu_to_use, 
+            minimum_length,
+            threshold,
+            conserved,
+            chewie_schema=True, 
+            show_progress=True)
+    else:
+        # create pre-computed data
+        pre_computed_data_path = schema_evaluator.create_pre_computed_data(
+            input_files, 
+            translation_table, 
+            output_file, 
+            cpu_to_use, 
+            minimum_length, 
+            threshold,
+            conserved,
+            show_progress=True)
+
+    schema_evaluator_main_path = os.path.join(
+        output_file, "SchemaEvaluator_pre_computed_data"
+    )
+
+    schema_evaluator_html_files_path = os.path.join(
+        output_file, "html_files"
+    )
+
+    # Copy the main.js files to the respective directories
+
+    # Global main.js
+    script_path = os.path.dirname(os.path.abspath(__file__))
+    shutil.copy(os.path.join(script_path, "SchemaEvaluator",
+                             "resources", "main.js"), schema_evaluator_main_path)
+
+    # translate and run MAFFT
+    if not light_mode:
+
+        # Translate loci
+        protein_file_path = schema_evaluator.create_protein_files(
+            input_files, 
+            pre_computed_data_path, 
+            cpu_to_use, 
+            minimum_length, 
+            translation_table, 
+            show_progress=True)
+
+        # Run MAFFT
+        schema_evaluator.run_mafft(
+            protein_file_path, cpu_to_use, show_progress=True)
+
+        # Write HTML files
+        schema_evaluator.write_individual_html(
+            input_files, pre_computed_data_path, protein_file_path, output_file)
+
+        # html_files main.js
+        shutil.copy(os.path.join(script_path, "SchemaEvaluator",
+                                 "resources", "main_ind.js"), schema_evaluator_html_files_path)
+
+    # remove intermediate files created
+    # during the report generation
+    if not no_cleanup:
+        # Removes pre-computed data in json format.
+        json_files = [
+            os.path.join(schema_evaluator_main_path, file)
+            for file in os.listdir(schema_evaluator_main_path)
+            if ".json" in file
+        ]
+
+        for jf in json_files:
+            os.remove(jf)
+
+        if not light_mode:
+            # Removes translated loci and MAFFT outputs.
+            prot_files_dir = os.path.join(
+                schema_evaluator_main_path, "prot_files")
+
+            shutil.rmtree(prot_files_dir)
+
+    print("The report has been created. Please open the schema_evaluator_report.html in the SchemaEvaluator_pre_computed_data directory.")
 
 
 def test_schema():
@@ -679,11 +788,12 @@ def test_schema():
     def msg(name=None):
         # simple command to evaluate genome quality
         simple_cmd = ('chewBBACA.py TestGenomeQuality -i <input_file> '
-                                                   '-n <max_iteration> '
-                                                   '-t <max_threshold>'
-                                                   '-s <step>')
+                      '-n <max_iteration> '
+                      '-t <max_threshold>'
+                      '-s <step>')
 
-        usage_msg = ('\nEvaluate genome quality with default parameters:\n  {0}\n'.format(simple_cmd))
+        usage_msg = (
+            '\nEvaluate genome quality with default parameters:\n  {0}\n'.format(simple_cmd))
 
         return usage_msg
 
@@ -744,18 +854,18 @@ def extract_cgmlst():
     def msg(name=None):
         # simple command to determine loci that constitute cgMLST
         simple_cmd = ('  chewBBACA.py ExtractCgMLST -i <input_file> '
-                                                   '-o <output_directory> ')
+                      '-o <output_directory> ')
 
         # command to determine cgMLST with custom threshold
         threshold_cmd = ('  chewBBACA.py ExtractCgMLST -i <input_file> '
-                                                   '-o <output_directory> '
-                                                   '\n\t\t\t     --p <threshold>')
+                         '-o <output_directory> '
+                         '\n\t\t\t     --p <threshold>')
 
         # command to get information about a single schema
         remove_cmd = ('  chewBBACA.py ExtractCgMLST -i <input_file> '
-                                                   '-o <output_directory> '
-                                                   '\n\t\t\t     --r <genes2remove> '
-                                                   '--g <genomes2remove>')
+                      '-o <output_directory> '
+                      '\n\t\t\t     --r <genes2remove> '
+                      '--g <genomes2remove>')
 
         usage_msg = ('\nDetermine cgMLST:\n{0}\n'
                      '\nDetermine cgMLST based on non-default threshold:\n{1}\n'
@@ -828,10 +938,11 @@ def remove_genes():
 
         # simple command to remove a set of genes from a matrix with allelic profiles
         simple_cmd = ('  chewBBACA.py RemoveGenes -i <input_file> '
-                                                   '-g <genes_list> '
-                                                   '-o <output_file>')
+                      '-g <genes_list> '
+                      '-o <output_file>')
 
-        usage_msg = ('\nRemove a set of genes from a matrix with allelic profiles:\n{0}\n'.format(simple_cmd))
+        usage_msg = (
+            '\nRemove a set of genes from a matrix with allelic profiles:\n{0}\n'.format(simple_cmd))
 
         return usage_msg
 
@@ -917,18 +1028,18 @@ def prep_schema():
 
         # simple command to adapt external schema with default arguments values
         simple_cmd = ('  chewBBACA.py PrepExternalSchema -i <input_files> '
-                                                      '-o <output_directory> '
-                                                      '--ptf <ptf_path> ')
+                      '-o <output_directory> '
+                      '--ptf <ptf_path> ')
 
         # command to adapt external schema with non-default arguments values
         params_cmd = ('  chewBBACA.py PrepExternalSchema -i <input_files> '
-                                                      '-o <output_directory> '
-                                                      '--ptf <ptf_path>\n'
-                                                      '\t\t\t\t  --cpu <cpu_cores> '
-                                                      '--bsr <blast_score_ratio> '
-                                                      '--l <minimum_length>\n'
-                                                      '\t\t\t\t  --t <translation_table> '
-                                                      '--st <size_threshold>')
+                      '-o <output_directory> '
+                      '--ptf <ptf_path>\n'
+                      '\t\t\t\t  --cpu <cpu_cores> '
+                      '--bsr <blast_score_ratio> '
+                      '--l <minimum_length>\n'
+                      '\t\t\t\t  --t <translation_table> '
+                      '--st <size_threshold>')
 
         usage_msg = ('\nAdapt external schema (one FASTA file per schema gene):\n\n{0}\n'
                      '\nAdapt external schema with non-default parameters:\n\n{1}\n'.format(simple_cmd, params_cmd))
@@ -1053,10 +1164,11 @@ def find_uniprot():
 
         # simple command to determine annotations for the loci in a schema
         simple_cmd = ('  chewBBACA.py UniprotFinder -i <input_files> '
-                                                   '-t <protein_table> '
-                                                   '--cpu <cpu_cores>')
+                      '-t <protein_table> '
+                      '--cpu <cpu_cores>')
 
-        usage_msg = ('\nFind annotations for loci in a schema:\n\n{0}\n'.format(simple_cmd))
+        usage_msg = (
+            '\nFind annotations for loci in a schema:\n\n{0}\n'.format(simple_cmd))
 
         return usage_msg
 
@@ -1101,15 +1213,15 @@ def download_schema():
     def msg(name=None):
         # simple command to download a schema from the NS
         simple_cmd = ('  chewBBACA.py DownloadSchema -sp <species_id> '
-                                                  '-sc <schema_id> '
-                                                  '-o <download_folder> ')
+                      '-sc <schema_id> '
+                      '-o <download_folder> ')
 
         # command to download a schema from the NS with non-default arguments values
         params_cmd = ('  chewBBACA.py DownloadSchema -sp <species_id> '
-                                                  '-sc <schema_id> '
-                                                  '-o <download_folder>\n'
-                                                  '\t\t\t      --cpu <cpu_cores> '
-                                                  '--ns <nomenclature_server_url> ')
+                      '-sc <schema_id> '
+                      '-o <download_folder>\n'
+                      '\t\t\t      --cpu <cpu_cores> '
+                      '--ns <nomenclature_server_url> ')
 
         usage_msg = ('\nDownload schema:\n{0}\n'
                      '\nDownload schema with non-default parameters:\n{1}\n'.format(simple_cmd, params_cmd))
@@ -1195,23 +1307,23 @@ def upload_schema():
     def msg(name=None):
         # simple command to load a schema to the NS
         simple_cmd = ('  chewBBACA.py LoadSchema -i <schema_directory> '
-                                              '-sp <species_id> '
-                                              '-sn <schema_name>\n'
-                                              '\t\t\t  -lp <loci_prefix> ')
+                      '-sp <species_id> '
+                      '-sn <schema_name>\n'
+                      '\t\t\t  -lp <loci_prefix> ')
 
         # command to load a schema to the NS with non-default arguments values
         params_cmd = ('  chewBBACA.py LoadSchema -i <schema_directory> '
-                                              '-sp <species_id> '
-                                              '-sn <schema_name>\n'
-                                              '\t\t\t  -lp <loci_prefix> '
-                                              '--thr <threads> '
-                                              '--ns <nomenclature_server_url>')
+                      '-sp <species_id> '
+                      '-sn <schema_name>\n'
+                      '\t\t\t  -lp <loci_prefix> '
+                      '--thr <threads> '
+                      '--ns <nomenclature_server_url>')
 
         # command to continue schema upload that was interrupted or aborted
         continue_cmd = ('  chewBBACA.py LoadSchema -i <schema_directory> '
-                                                '-sp <species_id> '
-                                                '-sn <schema_name>\n'
-                                                '\t\t\t  --continue_up')
+                        '-sp <species_id> '
+                        '-sn <schema_name>\n'
+                        '\t\t\t  --continue_up')
 
         usage_msg = ('\nLoad schema:\n{0}\n'
                      '\nLoad schema with non-default parameters:\n{1}\n'
@@ -1324,11 +1436,12 @@ def synchronize_schema():
 
         # command to synchronize a schema with its NS version with non-default arguments values
         params_cmd = ('  chewBBACA.py SyncSchema -sc <schema_directory> '
-                                                '--cpu <cpu_cores> '
-                                                '--ns <nomenclature_server_url>')
+                      '--cpu <cpu_cores> '
+                      '--ns <nomenclature_server_url>')
 
         # command to submit novel local alleles
-        submit_cmd = ('  chewBBACA.py SyncSchema -sc <schema_directory> --submit')
+        submit_cmd = (
+            '  chewBBACA.py SyncSchema -sc <schema_directory> --submit')
 
         usage_msg = ('\nSync schema:\n{0}\n'
                      '\nSync schema with non-default parameters:\n{1}\n'
@@ -1406,7 +1519,7 @@ def ns_stats():
 
         # command to get information about a single schema
         schema_cmd = ('  chewBBACA.py NSStats -m schemas --sp <species_id> '
-                                             '--sc <schema_id>')
+                      '--sc <schema_id>')
 
         usage_msg = ('\nList species and totals:\n{0}\n'
                      '\nList all schemas for a species and associated information:\n{1}\n'
@@ -1533,9 +1646,11 @@ def main():
             print('{0}: {1}'.format(f, functions_info[f][0]))
         sys.exit(0)
 
-    if len(sys.argv) > 1 and 'version' in sys.argv[1]:
+    matches = ["--v", "-v", "-version", "--version"]
+
+    if len(sys.argv) > 1 and any(m in sys.argv[1] for m in matches):
         print(version)
-        return
+        sys.exit(0)
 
     print('\nchewBBACA version: {0}'.format(version))
     print('Authors: {0}'.format(authors))
@@ -1552,6 +1667,7 @@ def main():
         print('Select one of the following functions:\n')
         for f in functions_info:
             print('{0}: {1}'.format(f, functions_info[f][0]))
+        sys.exit(0)
 
 
 if __name__ == "__main__":
